@@ -14,6 +14,7 @@
 #
 
 import json
+import logging
 
 from dataclasses import dataclass, field
 from typing import List
@@ -52,11 +53,18 @@ converters = {
 }
 
 
-def load_config(config_path) -> Configuration:
+def load_config(config_path, command_line_args=None) -> Configuration:
     # If this code is executed without an exception then we have a valid Configuration object
     with open(config_path) as f:
         raw_cfg = json.load(f)
 
+    #override config with user specified values
+    if command_line_args:
+        for arg in command_line_args:
+            if arg in raw_cfg and command_line_args[arg] is not None:
+                logging.info(f"Overriding config file argument {arg} with a command line arguments. Value changed from {raw_cfg[arg]} to {command_line_args[arg]}")
+                raw_cfg[arg] = command_line_args[arg]
+
     config = dacite.from_dict(
         data_class=Configuration, data=raw_cfg,
         config=dacite.Config(type_hooks=converters),
